##  Managing User
By default, changes to your workspace are made by the integration's service user account, and these changes will appear in the sync log under the username 'integration-signal.' If you prefer to have more specific control over permissions or want to use different usernames for various SAP Signavio integration configurations, you can select any of your technical users from the drop-down list.
After setting up authentication, click Next to proceed to the Basic Configuration tab.
YesNo
Send
![close icon](https://consent.trustarc.com/get?name=sapglow-close-icon.png)
This site uses cookies and related technologies, as described in our Cookie Statement, for purposes that may include site operation, analytics, enhanced user experience, or advertising. You may choose to consent to our use of these technologies, or manage your own preferences.
Understood Manage Settings
[Privacy Statement](https://help.sap.com/docs/privacy)|[Cookie Statement](https://www.sap.com/about/legal/privacy/cookies.html)
